==> mcu_plus_sdk_am263x_08_06_00_34_docs_only.tar.xz: mcu_plus_sdk_am263x_08_06_00_34_docs_only/docs/api_guide_am263x/group__SDL__DPL__MODULE.js <==
var group__SDL__DPL__MODULE =
[
    [ "sdl_dpl.h", "sdl__dpl_8h.html", null ],
    [ "SDL_DPL_HwipParams", "structSDL__DPL__HwipParams.html", [
      [ "intNum", "structSDL__DPL__HwipParams.html#adca42b99f629291d3c68b2a5dd24c050", null ],
      [ "callback", "structSDL__DPL__HwipParams.html#a486dcd26a28eb8cf607c19a9010dd720", null ],
      [ "callbackArg", "structSDL__DPL__HwipParams.html#a72c16b7f209d1f8da940ca3cc43d97b2", null ]
    ] ],
    [ "SDL_DPL_Interface", "structSDL__DPL__Interface.html", [
      [ "enableInterrupt", "structSDL__DPL__Interface.html#a7e68c86eff8104d0dcd0742adefe3fdc", null ],
      [ "disableInterrupt", "structSDL__DPL__Interface.html#a0e6b04f1ec55778ca98d78bcb67f1be3", null ],
      [ "registerInterrupt", "structSDL__DPL__Interface.html#a7b8fdb1d495bc9fa6682835dddedaf83", null ],
      [ "deregisterInterrupt", "structSDL__DPL__Interface.html#a068b0deec4e4d1de58f44e05616f85f2", null ],
      [ "delay", "structSDL__DPL__Interface.html#afe8e28ed1a71f1976821d8f28788fa0a", null ],
      [ "addrTranslate", "structSDL__DPL__Interface.html#a12de7e5720213226df1117edd88b3d58", null ]
    ] ],
    [ "pSDL_DPL_InterruptCallbackFunction", "group__SDL__DPL__MODULE.html#ga90dd06d6f69b5ed3dbb53e4e447001ac", null ],
    [ "pSDL_DPL_HwipHandle", "group__SDL__DPL__MODULE.html#gad63eb0de40d239b9b4ff420d2f62f36a", null ],
    [ "pSDL_DPL_InterruptFunction", "group__SDL__DPL__MODULE.html#ga27b0c93cd34e4337e3557b1d4e385740", null ],
    [ "pSDL_DPL_RegisterFunction", "group__SDL__DPL__MODULE.html#gaa1bdae0f5981b30180a51addc411bb9f", null ],
    [ "pSDL_DPL_DeregisterFunction", "group__SDL__DPL__MODULE.html#ga0fce25c12330fe219a07559686902afa", null ],
    [ "pSDL_DPL_DelayFunction", "group__SDL__DPL__MODULE.html#ga255bf9d74dd4518cedc80ee78d2a6501", null ],
    [ "pSDL_DPL_AddrTranslateFunction", "group__SDL__DPL__MODULE.html#ga1a80ecbe17eb742e66ae4f979a05736b", null ],
    [ "SDL_DPL_init", "group__SDL__DPL__MODULE.html#ga4538516a80bcb6c5af394a68e7b91fbb", null ],
    [ "SDL_DPL_enableInterrupt", "group__SDL__DPL__MODULE.html#gaf639702b531be398f258d3fb169c44ce", null ],
    [ "SDL_DPL_disableInterrupt", "group__SDL__DPL__MODULE.html#ga3a4d0ff2ada9172b09af32fde7afb2db", null ],
    [ "SDL_DPL_registerInterrupt", "group__SDL__DPL__MODULE.html#ga640294d2c1ffb6d00677f1566da0ad96", null ],
    [ "SDL_DPL_deregisterInterrupt", "group__SDL__DPL__MODULE.html#ga1a7c12cf308ddf92ef67e65e2b2f34be", null ],
    [ "SDL_DPL_delay", "group__SDL__DPL__MODULE.html#ga189e76e6f862cddde45fe3cedb603974", null ],
    [ "SDL_DPL_addrTranslate", "group__SDL__DPL__MODULE.html#ga89610badd4ed9666ad5e79177fa53c83", null ]
];

==> mcu_plus_sdk_am263x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am263x_11_01_00_19_docs_only/docs/api_guide_am263x/group__SDL__DPL__MODULE.js <==
var group__SDL__DPL__MODULE =
[
    [ "sdl_dpl.h", "sdl__dpl_8h.html", null ],
    [ "SDL_DPL_HwipParams", "structSDL__DPL__HwipParams.html", [
      [ "intNum", "structSDL__DPL__HwipParams.html#adca42b99f629291d3c68b2a5dd24c050", null ],
      [ "callback", "structSDL__DPL__HwipParams.html#a486dcd26a28eb8cf607c19a9010dd720", null ],
      [ "callbackArg", "structSDL__DPL__HwipParams.html#a72c16b7f209d1f8da940ca3cc43d97b2", null ]
    ] ],
    [ "SDL_DPL_Interface", "structSDL__DPL__Interface.html", [
      [ "enableInterrupt", "structSDL__DPL__Interface.html#a7e68c86eff8104d0dcd0742adefe3fdc", null ],
      [ "disableInterrupt", "structSDL__DPL__Interface.html#a0e6b04f1ec55778ca98d78bcb67f1be3", null ],
      [ "registerInterrupt", "structSDL__DPL__Interface.html#a7b8fdb1d495bc9fa6682835dddedaf83", null ],
      [ "deregisterInterrupt", "structSDL__DPL__Interface.html#a068b0deec4e4d1de58f44e05616f85f2", null ],
      [ "delay", "structSDL__DPL__Interface.html#afe8e28ed1a71f1976821d8f28788fa0a", null ],
      [ "globalDisableInterrupts", "structSDL__DPL__Interface.html#a97dd526740d50b560ff936a45c67cf1f", null ],
      [ "globalRestoreInterrupts", "structSDL__DPL__Interface.html#aebfc4f871112388997a711b50b2dbaed", null ],
      [ "addrTranslate", "structSDL__DPL__Interface.html#a12de7e5720213226df1117edd88b3d58", null ]
    ] ],
    [ "pSDL_DPL_InterruptCallbackFunction", "group__SDL__DPL__MODULE.html#ga90dd06d6f69b5ed3dbb53e4e447001ac", null ],
    [ "pSDL_DPL_HwipHandle", "group__SDL__DPL__MODULE.html#gad63eb0de40d239b9b4ff420d2f62f36a", null ],
    [ "pSDL_DPL_InterruptFunction", "group__SDL__DPL__MODULE.html#ga27b0c93cd34e4337e3557b1d4e385740", null ],
    [ "pSDL_DPL_RegisterFunction", "group__SDL__DPL__MODULE.html#gaa1bdae0f5981b30180a51addc411bb9f", null ],
    [ "pSDL_DPL_DeregisterFunction", "group__SDL__DPL__MODULE.html#ga0fce25c12330fe219a07559686902afa", null ],
    [ "pSDL_DPL_DelayFunction", "group__SDL__DPL__MODULE.html#ga255bf9d74dd4518cedc80ee78d2a6501", null ],
    [ "pSDL_DPL_AddrTranslateFunction", "group__SDL__DPL__MODULE.html#ga1a80ecbe17eb742e66ae4f979a05736b", null ],
    [ "pSDL_DPL_globalDisableInterruptsFunction", "group__SDL__DPL__MODULE.html#gaa1a0c4dbcea5894207f0774892479188", null ],
    [ "pSDL_DPL_globalRestoreInterruptsFunction", "group__SDL__DPL__MODULE.html#ga3a93b8a409de3a90e4e10131c7f37c67", null ],
    [ "SDL_DPL_init", "group__SDL__DPL__MODULE.html#ga4538516a80bcb6c5af394a68e7b91fbb", null ],
    [ "SDL_DPL_enableInterrupt", "group__SDL__DPL__MODULE.html#gaf639702b531be398f258d3fb169c44ce", null ],
    [ "SDL_DPL_disableInterrupt", "group__SDL__DPL__MODULE.html#ga3a4d0ff2ada9172b09af32fde7afb2db", null ],
    [ "SDL_DPL_registerInterrupt", "group__SDL__DPL__MODULE.html#ga640294d2c1ffb6d00677f1566da0ad96", null ],
    [ "SDL_DPL_deregisterInterrupt", "group__SDL__DPL__MODULE.html#ga1a7c12cf308ddf92ef67e65e2b2f34be", null ],
    [ "SDL_DPL_delay", "group__SDL__DPL__MODULE.html#ga189e76e6f862cddde45fe3cedb603974", null ],
    [ "SDL_DPL_addrTranslate", "group__SDL__DPL__MODULE.html#ga89610badd4ed9666ad5e79177fa53c83", null ],
    [ "SDL_DPL_globalDisableInterrupts", "group__SDL__DPL__MODULE.html#gab6bcd1ab8e42006166e7a1cea8af6505", null ],
    [ "SDL_DPL_globalRestoreInterrupts", "group__SDL__DPL__MODULE.html#gafa675936e17caa7becda15fac83da627", null ]
];
